<?php

namespace Everyware\Plugin\PresentationPreview;

use Everyware\Plugin\PresentationPreview\Contracts\PreviewData;
use Everyware\Plugin\PresentationPreview\Exceptions\InvalidDataException;
use Infomaker\Everyware\Support\GenericPropertyObject;

class ArticlePreview extends GenericPropertyObject implements PreviewData
{
    /**
     * @throws InvalidDataException
     */
    public function __construct(string $data)
    {
        $this->fill($this->getValidData($data));
    }

    public function getContent(): string
    {
        return $this->getSingleValue('content');
    }

    public function getImengineUri(): string
    {
        $meta = $this->getMetaData();

        return $meta['imengine'] ?? '';
    }

    public function getMetaData(): array
    {
        return $this->getMultiValue('meta');
    }

    public function getRelatedArticles(): array
    {
        $meta = $this->getMetaData();

        return $meta['articles'] ?? [];
    }

    public function getRelatedConcepts(): array
    {
        $meta = $this->getMetaData();

        return $meta['concepts'] ?? [];
    }

    public function getUuid(): string
    {
        return $this->getSingleValue('uuid');
    }

    private function getValidData(string $bodyJson): array
    {
        try {
            $rawBody = json_decode($bodyJson, true, 512, JSON_THROW_ON_ERROR);

            if ( ! isset($rawBody['data'])) {
                throw new InvalidDataException('No data provided');
            }

            $data = $rawBody['data'];

            if(! isset($data['uuid'], $data['content'], $data['meta']) ) {
                throw new InvalidDataException('Invalid data! missing one or more properties.');
            }

            return $data;
        } catch (\JsonException $e) {
            throw new InvalidDataException($e->getMessage());
        }
    }
}
