<?php declare(strict_types=1);

namespace Everyware\Plugin\PresentationPreview;

use Everyware\Plugin\PresentationPreview\Contracts\PreviewData;
use Everyware\Plugin\PresentationPreview\Contracts\PreviewRenderer;

class ArticlePreviewRenderer implements PreviewRenderer
{
    public const PREVIEW_FILE = 'previews/single-article.php';

    public function render(PreviewData $data): void
    {
        $themeFile = locate_template(static::PREVIEW_FILE);

        if (empty($themeFile)) {
            $themeFile = __DIR__ . "/" . static::PREVIEW_FILE;
        }

        // Setup variables that should be available to the template.
        extract([
            'previewData' => $data
        ], EXTR_OVERWRITE);


        add_action('wp_head', [$this, 'renderHeadMeta']);

        if (file_exists($themeFile)) {
            require_once $themeFile;
        }
    }

    public function renderHeadMeta(): void
    {
        if (PreviewSettings::shouldAddBaseTag()) {
            echo sprintf('<base href="%s" />', $this->getBaseTagUrl());
        }
    }

    public function getBaseTagUrl(): string
    {
        return sprintf(
            '%s://%s',
            filter_var($_SERVER['HTTPS'] ?? 'off', FILTER_VALIDATE_BOOL) ? 'https' : 'http',
            $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']
        );
    }
}
