<?php declare(strict_types=1);

namespace Everyware\Plugin\PresentationPreview;

use Exception;

class Plugin
{
    public function hijackApiRequests(): void
    {
        $router = new Router(new Request(new Input()));

        if ($router->isApiRequest()) {
            try {
                $router->setupAPI();

                if ($router->expectsContent()) {
                    ob_start();
                    $router->renderPreview(new ArticlePreviewRenderer());
                    $preview = ob_get_clean();

                    wp_send_json_success(['content' => $preview]);
                }

                wp_send_json('');

            } catch (Exception $e) {
                $errorCode = $e->getCode();

                if ($errorCode >= 400) {
                    wp_send_json_error(['message' => $e->getMessage()], $errorCode);
                }

                wp_send_json_error(['message' => $e->getMessage()]);
            }
        }
    }

    public static function init(): Plugin
    {
        $instance = new static();

        add_action('wp_loaded', [$instance, 'hijackApiRequests']);

        return $instance;
    }
}
