<?php

namespace Everyware\Plugin\PresentationPreview;

use Everyware\Plugin\PresentationPreview\Exceptions\InvalidDataException;

class Request
{
    private Input $input;

    public function __construct(Input $input)
    {
        $this->input = $input;
    }
    public function getMethod(): string
    {
        return $_SERVER['REQUEST_METHOD'] ?? '';
    }

    public function getContentType(): string
    {
        return $_SERVER['CONTENT_TYPE'] ?? '';
    }

    public function isJsonRequest(): bool
    {
        return $this->hasContentType('application/json');
    }

    public function hasContentType(string $type): bool
    {
        if (isset($_SERVER['HTTP_CONTENT_TYPE'], $_SERVER['CONTENT_TYPE'])) {
            return $_SERVER['CONTENT_TYPE'] === $type;
        }

        return false;
    }

    public function getPath(): string
    {
        return trim(parse_url(add_query_arg([]), PHP_URL_PATH), '/');
    }

    public function isPath(string $path): bool
    {
        return $path === $this->getPath();
    }

    public function getBody(): string
    {
        $rawBody = $this->input->get();

        if (empty($rawBody)) {
            throw new InvalidDataException('No data provided');
        }

        return $rawBody;
    }
}
